import functools
from datetime import datetime


def run_time(func):
    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        start_time = datetime.now()
        _return = func(*args, **kwargs)
        end_time = datetime.now()
        print(f">> [{func.__name__}] run time: {end_time - start_time}")
        return _return

    return wrapper


def run_count(func):
    count = 0

    @functools.wraps(func)
    def wrapper(*args, **kwargs):
        nonlocal count
        count += 1
        print(f">> [{func.__name__}] run count: {count}")
        return func(*args, **kwargs)

    return wrapper



from . import shell
from . import version
from .utils import run_time
from .utils import run_count

__version__ = version.VERSION

__all__ = [
    "shell",
    "version",
    "run_time",
    "run_count"
]



from setuptools import setup
from setuptools import find_packages

from torbjorn import version

NAME = "torbjorn"
AUTHOR = "Ailln"
EMAIL = "kinggreenhall@gmail.com"
URL = "https://github.com/HaveTwoBrush/torbjorn"
LICENSE = "MIT License"
DESCRIPTION = "Provide some practical Python decorators."

if __name__ == "__main__":
    setup(
        name=NAME,
        version=version.VERSION,
        author=AUTHOR,
        author_email=EMAIL,
        url=URL,
        license=LICENSE,
        description=DESCRIPTION,
        packages=find_packages(),
        include_package_data=True,
        install_requires=open("./requirements.txt", "r").read().splitlines(),
        long_description=open("./README.md", "r").read(),
        long_description_content_type='text/markdown',
        entry_points={
            "console_scripts": [
                "torbjorn=torbjorn.shell:run"
            ]
        },
        zip_safe=True,
        classifiers=[
            "Programming Language :: Python :: 3",
            "License :: OSI Approved :: MIT License",
            "Operating System :: OS Independent",
        ]
    )



import torbjorn as tbn


@tbn.run_time
@tbn.run_count
def calculate_million_numbers(num):
    number = 0
    for _ in range(num):
        number += 1


if __name__ == '__main__':
    for _ in range(5):
        calculate_million_numbers(1000000)
